#
# Cookbook:: esh_piped
# Recipe:: nginx
#
# Copyright:: 2022, https://easyself.host
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

apt_package 'nginx-full'

cookbook_file '/etc/nginx/nginx.conf' do
  owner 'root'
  group 'root'
  mode '0644'
  action :create
end

template '/etc/nginx/conf.d/pipedapi.conf' do
  owner 'root'
  group 'root'
  mode '0644'
  variables backend_hostname: "#{node['esh']['piped']['config']['backend_hostname']}.#{node['esh']['piped']['config']['domain']}"
  action :create
end

template '/etc/nginx/conf.d/pipedproxy.conf' do
  owner 'root'
  group 'root'
  mode '0644'
  variables proxy_hostname: "#{node['esh']['piped']['config']['proxy_hostname']}.#{node['esh']['piped']['config']['domain']}"
  action :create
end

template '/etc/nginx/conf.d/pipedfrontend.conf' do
  owner 'root'
  group 'root'
  mode '0644'
  variables frontend_hostname: "#{node['esh']['piped']['config']['frontend_hostname']}.#{node['esh']['piped']['config']['domain']}"
  action :create
end

cookbook_file '/etc/nginx/snippets/ytproxy.conf' do
  owner 'root'
  group 'root'
  mode '0644'
  action :create
end

service 'nginx' do
  action :nothing
  subscribes :restart, 'file[/etc/nginx/nginx.conf]', :immediately
  subscribes :restart, 'file[/etc/nginx/conf.d/pipedapi.conf]', :immediately
  subscribes :restart, 'file[/etc/nginx/conf.d/pipedproxy.conf]', :immediately
  subscribes :restart, 'file[/etc/nginx/conf.d/pipedfrontend.conf]', :immediately
  subscribes :restart, 'file[/etc/nginx/snippets/ytproxy.conf]', :immediately
end
