#
# Cookbook:: esh_piped
# Recipe:: postgresql
#
# Copyright:: 2022, https://easyself.host
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

postgresql_install 'install posgresql' do
  version '13'
  repo_pgdg false
  action :install_server
end

service 'postgresql@13-main' do
  action :nothing
end

additional_config = {
  'listen_addresses': "localhost,#{node['ipaddress']}",
}

postgresql_config 'update postgresql listen_addresses' do
  version '13'
  server_config additional_config
  notifies :restart, 'service[postgresql@13-main]'
end

postgresql_user 'piped' do
  password node['esh']['piped']['postgresql']['password']
  createdb true
end

postgresql_database 'piped' do
  owner 'piped'
end

postgresql_access 'piped_access' do
#  type 'host'
  database 'piped'
#  user 'piped'
  address '10.10.10.0/24'
  auth_method 'md5'
  notifies :reload, 'service[postgresql@13-main]', :immediately
end
